@@ -71,10 +71,20 @@ RcppExport SEXP oem_fit_big(SEXP x_,
     //   1/(2n) * ||y - X * beta||^2 + lambda * ||beta||_1
     // which is equivalent to minimizing
     //   1/2 * ||y - X * beta||^2 + n * lambda * ||beta||_1
-    ArrayXd lambda(as<ArrayXd>(lambda_));
+    //ArrayXd lambda(as<ArrayXd>(lambda_)); // old lambda code
     VectorXd weights(as<VectorXd>(weights_));
     VectorXd group_weights(as<VectorXd>(group_weights_));
-    int nlambda = lambda.size();
+    
+    
+    std::vector<VectorXd> lambda(as< std::vector<VectorXd> >(lambda_));
+    
+    VectorXd lambda_tmp;
+    lambda_tmp = lambda[0];
+    
+    int nl = as<int>(nlambda_);
+    VectorXd lambda_base(nl);
+    
+    int nlambda = lambda_tmp.size();
     
     
     List opts(opts_);
@@ -126,13 +136,19 @@ RcppExport SEXP oem_fit_big(SEXP x_,
     lmax = solver->compute_lambda_zero(); // 
     
     
-    if (nlambda < 1) {
-        
+    bool provided_lambda = false;
+    if (nlambda < 1) 
+    {
         double lmin = as<double>(lmin_ratio_) * lmax;
-        lambda.setLinSpaced(as<int>(nlambda_), std::log(lmax), std::log(lmin));
-        lambda = lambda.exp();
-        nlambda = lambda.size();
         
+        lambda_base.setLinSpaced(nl, std::log(lmax), std::log(lmin));
+        lambda_base = lambda_base.array().exp();
+        nlambda = lambda_base.size();
+        
+        lambda_tmp.resize(nlambda);
+    } else
+    {
+        provided_lambda = true;
     }
     
     
@@ -145,6 +161,8 @@ RcppExport SEXP oem_fit_big(SEXP x_,
     int nlambda_store = nlambda;
     double ilambda = 0.0;
     
+    std::string elasticnettxt(".net");
+    
     for (unsigned int pp = 0; pp < penalty.size(); pp++)
     {
         if (penalty[pp] == "ols")
@@ -152,13 +170,35 @@ RcppExport SEXP oem_fit_big(SEXP x_,
             nlambda = 1L;
         }
         
+        bool is_net_pen = penalty[pp].find(elasticnettxt) != std::string::npos;
+        
+        if (provided_lambda)
+        {
+            lambda_tmp = lambda[pp];
+        } else 
+        {
+            if (is_net_pen)
+            {
+                lambda_tmp = (lambda_base.array() / alpha).matrix(); // * n; // 
+            } else
+            {
+                lambda_tmp = lambda_base; // * n; // 
+            }
+        }
+        
         VectorXd loss(nlambda);
         loss.fill(1e99);
         
         for(int i = 0; i < nlambda; i++)
         {
             
-            ilambda = lambda[i]; // * n; //     
+            if (i % 3 == 0)
+            {
+                Rcpp::checkUserInterrupt();
+            }
+            
+            ilambda = lambda_tmp(i);
+            
             if(i == 0)
                 solver->init(ilambda, penalty[pp],
                              alpha, gamma, tau);
@@ -185,6 +225,8 @@ RcppExport SEXP oem_fit_big(SEXP x_,
             
         } //end loop over lambda values
         
+        lambda[pp] = lambda_tmp;
+        
         if (penalty[pp] == "ols")
         {
             // reset to old nlambda
